import React, { Component } from 'react';
import { Alert, StyleSheet } from 'react-native';
import Swipeout from 'react-native-swipeout';
import { connect } from 'react-redux';
import { Body, Button, Icon, List, ListItem, Left, Right, Text, Thumbnail } from 'native-base';

import { removeItem } from '../actions/cartActions';
import I18n from "../i18n/i18n";

class CartItems extends Component {

    state = { activeRowKey: null }

    render(){
        const swipeSettings = {
            autoClose: true,
            onClose: (secId, rowId, direction) => { this.setState({activeRowKey: null})},
            onOpen: (secId, rowId, direction) => { this.setState({activeRowKey: this.props.item.id})},
            right: [
                {
                    onPress: () => {
                        const deleteRow = this.state.activeRowKey;
                        Alert.alert(
                            I18n.t('deleteItem'),
                            I18n.t('deleteItemText'),
                            [
                            {text: I18n.t('cancelButton'), onPress:() => console.log('Cancel Pressed'), style: 'cancel'},
                            {text: I18n.t('yesRemoveButton'), onPress:() => { this.props.removeItem({ index: this.props.index, item: this.props.item }) }},
                            ],
                            { cancelable: true}
                        )
                    },
                    text: <Icon type="Feather" name="trash" style={{fontSize: 20, color: "#fff"}} />, type: 'delete'
                }
            ],
            rowId: this.props.index,
            sectionId: 1
        }
        const { item, index } = this.props;
        return (
            <Swipeout {...swipeSettings} style={styles.swipe}>
                <List>
                    <ListItem thumbnail>
                        <Left>
                            <Thumbnail square source={item.picture} style={{borderRadius: 30/2}} />
                        </Left>
                        <Body style={styles.body}>
                            <Text>{item.title}</Text>
                            <Text>{I18n.t('currency')}{(item.cost).toFixed(2)}</Text>
                        </Body>
                    </ListItem>
                </List>
            </Swipeout>
        );
    }
}

const styles = StyleSheet.create({
    swipe: {
        backgroundColor: '#fff'
    },
    body: {
        borderBottomWidth: 0
    },
    right: {
        borderBottomWidth: 0
    }
});

export default connect(null, { removeItem } )(CartItems);