import React, { Component } from 'react'; 
import { StyleSheet, TouchableOpacity, View } from 'react-native';
import { Body, Button, Container, Content, Footer, Header, Icon, Left, List, ListItem, Text } from 'native-base';
import { connect } from 'react-redux';
import { Actions } from 'react-native-router-flux';

import { logoutUser } from "../actions/auth.actions";
import { logoutUser_2 } from "../actions/auth.actions";

import I18n from "../i18n/i18n";

class Menu extends Component {

  logoutUser = () => { this.props.dispatch(logoutUser()) }
  home() { Actions.home() }
  orders() { Actions.orders() }
  cart() { Actions.cart() }
  profile() { Actions.profile() }

  render(){
    const {getUser: {userDetails}} = this.props; 
    return(
      <Container style={styles.container}>
        <Header androidStatusBarColor="#102027" span = {true} style={styles.header}>
          <Button transparent onPress={this.profile}>
            <View style={styles.profileView}>
              <Icon type="Feather" name="user" style={styles.headerIcon} />
              <Text style={styles.userEmail}>{userDetails ? userDetails.email : "Unknown"}</Text>
            </View>
          </Button>
        </Header>
        <Content>
          <List>
            <ListItem icon onPress={this.home}>
              <Left>
                  <Icon type="Feather" name="home" style={styles.icon}/>
              </Left>
              <Body>
                <Text>{I18n.t('homeHeader')}</Text>
              </Body>
            </ListItem>
            <ListItem icon onPress={this.orders}>
              <Left>
                  <Icon type="Feather" name="shopping-bag" style={styles.icon}/>
              </Left>
              <Body>
                <Text>{I18n.t('ordersHeader')}</Text>
              </Body>
            </ListItem>
            <ListItem icon onPress={this.cart}>
              <Left>
                  <Icon type="Feather" name="shopping-cart" style={styles.icon}/>
              </Left>
              <Body>
                <Text>{I18n.t('cartHeader')}</Text>
              </Body>
            </ListItem>
          </List>
        </Content>
        <TouchableOpacity onPress={this.logoutUser}>
          <Footer style={styles.footer}>
              <Icon type="Feather" name="log-out" style={styles.logoutIcon} />
          </Footer>
        </TouchableOpacity>
      </Container>
    );
  }
}

const styles = StyleSheet.create({
  header: {
    backgroundColor: "#102027", 
    alignItems: "center"
  },
  headerIcon: {
    fontSize: 50, 
    color: '#fff'
  },
  profileView: {
    alignItems: 'center'
  },
  userEmail: {
    paddingTop: 5
  },
  icon: {
    fontSize: 20, 
    color: "#102027"
  },
  footer: {
    alignItems: 'center',
    backgroundColor: "#102027",
  },
  logoutIcon: {
      fontSize: 20,
      color: '#fff'
  },  
});

mapStateToProps = (state) => ({ getUser: state.userReducer.getUser });
mapDispatchToProps = (dispatch) => ({ dispatch }); 

export default connect(mapStateToProps, mapDispatchToProps)(Menu);