import React, { Component } from 'react';
import { Alert, StyleSheet } from 'react-native';
import { Button, Text } from 'native-base';
import { connect } from 'react-redux';

import { addOrder } from '../actions/orderAction';
import { emptyCart } from '../actions/cartActions';

import I18n from "../i18n/i18n";

class OrderButton extends Component {

    onPressButton = () => {
        Alert.alert(
            I18n.t('buyProducts'),
            I18n.t('buyButtonAlertText'),
            [
                {
                    text: I18n.t('yesBuyButton'), 
                    onPress: () => this.onPressYes()
                },
                {
                    text: I18n.t('cancelButton'),
                    onPress: () => console.log('Cancel Pressed'),
                    style: 'cancel',
                },
            ],
        );
    }

    onPressYes = () => {
        const { cartItems, addOrder, emptyCart } = this.props;
        addOrder({cartItems: cartItems});
        emptyCart();
    }

  render() {
    return (
        <Button small style={styles.button} onPress={this.onPressButton}>
            <Text style={styles.buttonText}>{I18n.t('buyButton')}</Text>
        </Button>
    );
  }
}

const styles = StyleSheet.create({
    button: {
        backgroundColor: "#fff",  
    },
    buttonText: {
        color: "#102027",
    }
});

const mapStateToProps = (state) => ({ cartItems: state.cartReducer.cart })

export default connect(mapStateToProps, { addOrder, emptyCart })(OrderButton);