import React, { Component } from 'react';
import { Image, StyleSheet } from 'react-native';
import { Body, Button, Card, CardItem, Icon, Left, Right, Text } from 'native-base';


import I18n from "../i18n/i18n";

export default class ProductCard extends Component {

    constructor(props){
        super(props); 
        this.state = {
            show: false
        }
    }

    addToCart = () => { this.props.addItemsToCart(this.props.item) }
    showDescription = () =>{ this.setState({ show: true }) }; 
    hideDescription = () => { this.setState({ show: false }) }

    render() {
        const { product } = this.props
        return (
            <Card transparent style={styles.card}>
                <CardItem cardBody>
                    <Image source={product.picture} style={styles.image} />
                </CardItem>
                <CardItem>
                    <Left>
                        <Body>
                            <Text>{product.title}</Text>
                            <Text note>{product.note}</Text>
                            <Text>{product.cost}</Text>
                        </Body>
                    </Left>
                    <Right>
                        <Button small rounded style={styles.button} onPress={this.addToCart}>
                            <Text style={{fontSize: 12}}>{I18n.t('addToCartButton')}</Text>
                        </Button>
                    </Right>
                </CardItem>
                <CardItem>
                    <Body>
                        <Button rounded block style={styles.button} onPress={!this.state.show ? this.showDescription : this.hideDescription}>
                            {this.state.show && <Icon type="Feather" name="arrow-up" style={{color: "#fff"}}/>}
                            {!this.state.show && <Icon type="Feather" name="arrow-down" style={{color: "#fff"}}/>}
                        </Button>
                    </Body>
                </CardItem>
                {this.state.show && 
                    <CardItem>
                        <Body>
                            <Text>{product.description}</Text>
                        </Body>
                    </CardItem>
                }
            </Card>
        );
    }
}

const styles = StyleSheet.create({
    card: {
        borderBottomWidth: 1, 
        borderBottomColor: "#102027"
    },
    image: {
        height: 250,
        width: 0, 
        flex: 1, 
        resizeMode: "cover",
        borderRadius: 30/2,
    },
    icon: {
        color: "#102027"
    },
    button: {
        backgroundColor: "#102027",  
    },
})