import React, { Component } from 'react';
import { StyleSheet, View } from 'react-native';
import { connect } from 'react-redux';
import { Body, Button, Container, Drawer, Footer, Grid, Icon, Right, Row, Text } from 'native-base';
import { Actions } from 'react-native-router-flux';

import I18n from "../i18n/i18n";
import Menu from '../components/Menu';
import OrderButton from '../components/OrderButton'; 
import OrderItems from '../components/OrderItems';
import CustomHeader from '../components/CustomHeader';

export class Cart extends Component {

    home() { Actions.home() }
    closeDrawer = () => { this.drawer._root.close() };
    openDrawer = () => { this.drawer._root.open() };

    render() {
        const { cartItems, cartTotal } = this.props;
        return (
            <Drawer
                ref={(ref) => {this.drawer = ref}}
                content={<Menu navigator={this.navigator} />}
                onClose={() => this.closeDrawer()}>
                <Container>
                    <CustomHeader name={I18n.t('cartHeader')} onPressMenu={() => this.openDrawer()}/>
                    {((cartTotal).toFixed(2)) == 0 ? 
                        <Grid>
                            <Row style={styles.rowContainer}>
                                <Grid>
                                    <Row style={styles.row}>
                                        <Text style={styles.emptyCartText}>{I18n.t('emptyCartText')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        <Button iconRight style={styles.emptyCartButton} onPress={this.home}>
                                            <Text style={styles.emptyCartButtonText}>{I18n.t('emptyCartButtonText')}</Text>
                                            <Icon type="Feather" name="arrow-right" />
                                        </Button>
                                    </Row>
                                </Grid>
                            </Row>
                        </Grid> :
                        <OrderItems cartItems={cartItems} cartTotal={cartTotal} />
                    }
                    <Footer style={styles.footer}>
                        <Body style={styles.footerBody}>
                            <Text style={styles.price}>{I18n.t('sum')} {(cartTotal).toFixed(2)}</Text>
                        </Body>
                        <Right style={styles.footerRight}>
                            {((cartTotal).toFixed(2)) == 0 ? 
                                <Button small style={styles.button}>
                                    <Text style={styles.buttonText}>{I18n.t('buyButton')}</Text>
                                </Button>
                            : 
                                <OrderButton />
                            }
                        </Right>
                    </Footer>
                </Container>
            </Drawer>
        );
    }
}

const styles = StyleSheet.create({
    rowContainer: {
        alignItems: 'center',
        justifyContent: 'center'
    }, 
    row: {
        height: 'auto',
        justifyContent: 'center',
        alignItems: 'center'
    },
    emptyCartContainer: {
        alignItems: 'center',
    },  
    emptyCartText: {
        fontSize: 20,
        color: "#102027",
        marginTop: 10,
        marginBottom: 10
    },
    emptyCartButton: {
        backgroundColor: "#102027",
        borderRadius: 30/2
    },  
    icon: {
      color: "#fff",
      fontSize: 20
    },
    button: {
        backgroundColor: "grey",  
    },
    buttonText: {
        color: "#102027",
    },
    footer: {
      alignItems: 'center',
      backgroundColor: "#102027",
    },
    price: {
        fontSize: 16,
        color: '#fff'
    },
    footerRight: {
      paddingRight: 10
    },
    footerBody: {
      paddingLeft: 10
    }
});

const mapStateToProps = (state) => ({
    cartItems: state.cartReducer.cart,
    cartTotal: state.cartReducer.total
});

export default connect( mapStateToProps )(Cart);