import React, { Component } from 'react';
import { FlatList } from 'react-native';
import { connect } from 'react-redux';
import { Container, Drawer } from 'native-base';

import { fetchProducts } from '../actions/productAction';
import { addToCart } from '../actions/cartActions';
import { Actions } from 'react-native-router-flux';

import I18n from "../i18n/i18n";
import CustomHeader from '../components/CustomHeader';
import Menu from '../components/Menu';
import Product from '../components/Product';

class Home extends Component {

    constructor(props) { super(props) }
    componentWillMount = () => {    this.props.fetchProducts() }
    addItemsToCart = (product) => { this.props.addToCart(product) }
    closeDrawer = () => { this.drawer._root.close() };
    openDrawer = () => { this.drawer._root.open() };
    cart() { Actions.cart() }

    render() {
        const { products } = this.props; 
        return (
            <Drawer
                ref={(ref) => {this.drawer = ref}}
                content={<Menu navigator={this.navigator} />}
                onClose={() => this.closeDrawer()} >
                <Container>
                    <CustomHeader name={I18n.t('homeHeader')} onPressMenu={() => this.openDrawer()}/>
                    <FlatList 
                    //Data to cycle through
                    data={products} 
                    renderItem={({item}) => 
                        <Product 
                            item={item} 
                            addItemsToCart={this.addItemsToCart} 
                            product={item} />}
                            keyExtractor ={(item) => item.id} />
                </Container>
            </Drawer>
        );
    }
}

mapStateToProps = (state) => ({ products: state.productReducer.items });

export default connect(mapStateToProps, {addToCart, fetchProducts})(Home);