import React, { Component } from 'react';
import { Alert, StatusBar, View, StyleSheet, TouchableOpacity } from 'react-native';
import { Field, reduxForm } from 'redux-form';
import { Button, Container, Grid, Row, Text } from "native-base"; 
import { connect } from 'react-redux';
import { compose } from 'redux';  
import { Actions } from 'react-native-router-flux';

import I18n from "../i18n/i18n";
import InputText from '../components/InputText';
import {loginUser} from '../actions/auth.actions';
import Loader from '../components/Loader';

class Login extends Component {

  signup() { Actions.signup() }
  loginUser = async (values) => { 
    try {
      const response = await this.props.dispatch(loginUser(values))
      console.log(response);
      if (!response.success){
        throw response
      }
    } catch (error) {
      console.log(error);
      Alert.alert(
        I18n.t('loginFailed'),
        I18n.t('loginFailedDescription'),
        [
          {
            text: I18n.t('cancelButton'),
            onPress: () => console.log('Cancel Pressed'),
            style: 'cancel',
          },
        ],
      );
    }
     
    
  }
  onSubmit = (values) => { this.loginUser(values) }

  renderTextInput = (field) => {
      const {meta: {touched, error}, label, secureTextEntry, maxLength, keyboardType, placeholder, input: {onChange, ...restInput}} = field;
      return (
          <View>
              <InputText
                  onChangeText={onChange}
                  maxLength={maxLength}
                  placeholder={placeholder}
                  keyboardType={keyboardType}
                  secureTextEntry={secureTextEntry}
                  label={label}
                  {...restInput} />
                  {(touched && error) && <Text style={{marginBottom: 10, fontSize: 14, color: 'red', marginTop: 0}}>{error}</Text>} 
          </View>
      )
  }

  render() {
    const {handleSubmit, loginUser} = this.props;
    return ( 
      <Container style={styles.container}>
        {(loginUser && loginUser.isLoading) && <Loader />}
        <StatusBar backgroundColor="#102027" barStyle="light-content" />
        <Grid style={styles.gridContainer}>
          <Row style={styles.rowContainer}>
            <Grid style={styles.grid}>
              <Row style={styles.rowTitle}>
                <Text style={styles.title}>{I18n.t('loginTitle')}</Text>
              </Row>
              <Row style={styles.row}>
                <Text>{I18n.t('emailLabel')}</Text>
              </Row>
              <Row style={styles.row}>
                <Field
                  name="email"
                  placeholder={I18n.t('emailLabel')}
                  component={this.renderTextInput} 
                />
              </Row>
              <Row style={styles.row}>
                <Text>{I18n.t('passwordLabel')}</Text>
              </Row>
              <Row style={styles.row}>
                <Field
                  name="password"
                  placeholder={I18n.t('passwordLabel')}
                  secureTextEntry={true}
                  component={this.renderTextInput} 
                />
              </Row>
              <Row style={styles.rowButton}>
                  <View style={styles.signupContainer}>
                    <Text style={styles.signupText}>{I18n.t('noAccountText')}</Text>
                    <TouchableOpacity onPress={this.signup}>
                      <Text style={styles.signupText}> {I18n.t('signupRefText')}</Text>
                    </TouchableOpacity>
                  </View>
                  <Button style={styles.buttonLogin} onPress={handleSubmit(this.onSubmit)}>
                    <Text style={styles.loginText}>{I18n.t('loginButtonText')}</Text>
                  </Button>
              </Row>
            </Grid>
          </Row>
        </Grid>
      </Container>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    backgroundColor: "#102027"
  },
  gridContainer: {
    backgroundColor: '#102027', 
    justifyContent: 'center', 
    alignItems: 'center'
  },
  rowContainer: {
    height: 'auto', 
    backgroundColor: 'white', 
    width: 300, 
    borderWidth: 1, 
    borderColor: '#fff', 
    borderRadius: 30/2
  },
  grid: {
    alignItems: 'center'
  },
  rowTitle: {
    alignItems: 'flex-start', 
    width: 280, 
    height: 'auto', 
    marginTop: 10, 
    marginBottom: 20
  },
  rowButton: {
    alignItems: 'center', 
    width: 280, 
    height: 'auto', 
    justifyContent: 'space-between', 
    marginBottom: 10
  },
  title: {
    fontSize: 20
  },
  row: {
    alignItems: 'flex-start', 
    width: 280, 
    height: 'auto'
  },
  buttonLogin: {
    backgroundColor: "#102027",
    borderRadius: 30/2
  },
  loginText: {
      color: '#fff',
  },
  signupContainer: {
    justifyContent: 'center',
    flexDirection: 'row',
  }, 
  signupText: {
    color: '#102027', 
    fontSize: 16
  }
});

const validate = (values) => {
  const error = {};
  if(!values.email){ error.email = I18n.t('emailRequired') }
  if(!values.password){ error.password = I18n.t('passwordRequired') }
  return error; 
}

mapDispatchToProps = (dispatch) => ({ dispatch }); 

mapStateToProps = (state) => ({ loginUser: state.authReducer.loginUser });

export default compose(
    connect(mapStateToProps, mapDispatchToProps),
    reduxForm({ form: 'login', validate, }) 
)(Login)