import React, { Component } from 'react';
import { FlatList, StyleSheet, Text, View } from 'react-native';
import { Container, Drawer } from 'native-base';
import { connect } from 'react-redux';

import I18n from "../i18n/i18n";
import OrderSummary from '../components/OrderSummary';
import Menu from '../components/Menu';
import CustomHeader from '../components/CustomHeader';

import { Actions } from 'react-native-router-flux';

class Orders extends Component {

    getTotal(){
        let total = 0;
        const { items } = this.props;
        for (let i = 0; i < items.length; i++) {
            total = total + items[i].cost
        }
        return <Text style={styles.totText}>Total: ${(total).toFixed(2)}</Text>
    }

    closeDrawer = () => { this.drawer._root.close() };
    openDrawer = () => { this.drawer._root.open() };
    cart(){ Actions.cart() }

    render() {
        const { items } = this.props;
        return (
            <Drawer
                ref={(ref) => {this.drawer = ref}}
                content={<Menu navigator={this.navigator} />}
                onClose={() => this.closeDrawer()} >
                    <Container style={styles.contai}>
                        <CustomHeader name={I18n.t('ordersHeader')} onPressMenu={() => this.openDrawer()}/>
                        <FlatList
                            data={items}
                            renderItem={({item}) => <OrderSummary item={item} />}
                            keyExtractor={(item) => item.id}
                            ItemSeparatorComponent= {()=> <View style={styles.seperator} /> } />
                    </Container>
            </Drawer>
        );
    }
}

const styles = StyleSheet.create({
    seperator: {
        height:0.3,
        backgroundColor:'#102027'
    },
});

const mapStateToProps = (state) => ({
    customer: state.orderReducer.order.customer,
    items: state.orderReducer.order.items
})
export default connect(mapStateToProps)(Orders);