import React, { Component } from 'react';
import { StatusBar, View, StyleSheet, TouchableOpacity } from 'react-native';
import { Field, reduxForm } from 'redux-form';
import { compose } from 'redux'; 
import { Button, Container, Content, Drawer, Icon, Grid, Row, Text } from "native-base"; 
import { connect } from 'react-redux';

import { Actions } from 'react-native-router-flux';

import I18n from "../i18n/i18n";
import InputText from '../components/InputText';
import Menu from '../components/Menu';
import CustomHeader from '../components/CustomHeader';

class Profile extends Component {

    constructor(props){
        super(props); 
        this.state = {
            editProfile: false,
            editAccount: false,   
        }
    }

    closeDrawer = () => { this.drawer._root.close() };
    openDrawer = () => { this.drawer._root.open() };
    editProfile = () =>{ this.setState({ editProfile: true }) }; 
    saveProfile = () => { this.setState({ editProfile: false }) }
    editAccount = () =>{ this.setState({ editAccount: true }) }; 
    saveAccount = () => { this.setState({ editAccount: false }) }
    cart() { Actions.cart() }

    renderTextInput = (field) => {
        const {meta: {touched, error}, label, secureTextEntry, maxLength, keyboardType, placeholder, input: {onChange, ...restInput}} = field;
        return (
            <View>
                <InputText
                    onChangeText={onChange}
                    maxLength={maxLength}
                    placeholder={(touched && error) ? error : placeholder}
                    keyboardType={keyboardType}
                    secureTextEntry={secureTextEntry}
                    label={label}
                    {...restInput} />
            </View>
        )
    }

    render() {
        const {getUser: {userDetails}, handleSubmit} = this.props;
        return (
            <Drawer
                ref={(ref) => {this.drawer = ref}}
                content={<Menu navigator={this.navigator} />}
                onClose={() => this.closeDrawer()} >
                <Container>
                    <CustomHeader name="PROFILE" onPressMenu={() => this.openDrawer()}/>
                    <StatusBar backgroundColor="#102027" barStyle="light-content" />
                    <Content>
                        <Grid style={styles.gridContainer}>
                            <Row style={styles.rowContainer}>
                                <Grid style={styles.grid}>
                                    <Row style={styles.rowTitle}>
                                    <Text style={styles.title}>{I18n.t('profileDataTitle')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        <Text>{I18n.t('emailLabel')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        { this.state.editProfile ?
                                            <Field
                                                name="email"
                                                placeholder={I18n.t('emailLabel')}
                                                component={this.renderTextInput} 
                                            /> : 
                                            <Text style={styles.emailText}>{userDetails.email}</Text>
                                        }
                                    </Row>
                                    <Row style={styles.rowSave}>
                                        {this.state.editProfile == false ?
                                            <Button style={styles.buttonSave} onPress={this.editProfile}>
                                                <Icon type="Feather" name="edit" />  
                                            </Button> : 
                                            <Button style={styles.buttonSave} onPress={this.saveProfile}>
                                                <Icon type="Feather" name="save" />  
                                            </Button>
                                        }
                                    </Row>
                                </Grid>
                            </Row>
                            <Row style={styles.rowContainer}>
                                <Grid style={styles.grid}>
                                    <Row style={styles.rowTitle}>
                                    <Text style={styles.title}>{I18n.t('accountInformationTitle')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        <Text>{I18n.t('nameLabel')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        { this.state.editAccount ?
                                            <Field
                                                name="name"
                                                placeholder={I18n.t('nameLabel')}
                                                component={this.renderTextInput} 
                                            /> : 
                                            <Text style={styles.emailText}>{userDetails.name}</Text>
                                        }
                                    </Row>
                                    <Row style={styles.row}>
                                        <Text>{I18n.t('streetLabel')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        { this.state.editAccount ?
                                            <Field
                                                name="name"
                                                placeholder={I18n.t('streetLabel')}
                                                component={this.renderTextInput} 
                                            /> : 
                                            <Text style={styles.emailText}></Text>
                                        }
                                    </Row>
                                    <Row style={styles.row}>
                                        <Text>{I18n.t('postcodeAndCityLabel')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        { this.state.editAccount ?
                                            <Field
                                                name="name"
                                                placeholder={I18n.t('postcodeAndCityLabel')}
                                                component={this.renderTextInput} 
                                            /> : 
                                            <Text style={styles.emailText}></Text>
                                        }
                                    </Row>
                                    <Row style={styles.row}>
                                        <Text>{I18n.t('bankAccountLabel')}</Text>
                                    </Row>
                                    <Row style={styles.row}>
                                        { this.state.editAccount ?
                                            <Field
                                                name="name"
                                                placeholder={I18n.t('bankAccountLabel')}
                                                component={this.renderTextInput} 
                                            /> : 
                                            <Text style={styles.emailText}></Text>
                                        }
                                    </Row>
                                    <Row style={styles.rowSave}>
                                        <Button style={styles.buttonSave} onPress={!this.state.editAccount ? this.editAccount : this.saveAccount}>
                                            {this.state.editAccount && <Icon type="Feather" name="save" />}
                                            {!this.state.editAccount && <Icon type="Feather" name="edit" />}
                                        </Button>
                                    </Row>
                                </Grid>
                            </Row>
                        </Grid>
                    </Content>
                </Container>
            </Drawer>
        );
    }
}

const styles = StyleSheet.create({
    rowContainer: {
        margin: 5,
        height: 'auto',
        borderWidth: 1,
        borderColor: "#102027",
        borderRadius: 30/2
    },
    grid: {
        paddingLeft: 20
    },
    rowTitle: {
      alignItems: 'flex-start', 
      height: 'auto', 
      marginTop: 10, 
      marginBottom: 20
    },
    title: {
      fontSize: 20
    },
    row: {
      height: 'auto',
    },
    rowSave: {
        justifyContent: 'flex-end',
        width: 280,
        height: 'auto',
        marginBottom: 20
    }, 
    emailText: {
        fontWeight: "bold",
        paddingTop: 5,
        paddingBottom: 5
    },
    passwordText: {
        fontWeight: "bold",
        paddingTop: 5,
        paddingBottom: 5
    },
    buttonSave: {
        backgroundColor: "#102027",
        borderRadius: 30/2
    },
    saveText: {
        color: '#fff',
    },
});

mapStateToProps = (state) => ({ getUser: state.userReducer.getUser });
mapDispatchToProps = (dispatch) => ({ dispatch }); 

export default compose(
    connect(mapStateToProps, mapDispatchToProps),
    reduxForm({ form: 'profile' }) 
)(Profile)