import React, { Component } from 'react';
import  {StatusBar, View, StyleSheet, TouchableOpacity } from 'react-native';
import { Button, Container, Grid, Row, Text } from "native-base"; 
import { Field, reduxForm } from 'redux-form';
import { connect } from 'react-redux';
import { compose } from 'redux'; 

import { Actions } from 'react-native-router-flux';

import I18n from '../i18n/i18n';
import InputText from '../components/InputText';
import {createNewUser} from "../actions/auth.actions";
import Loader from "../components/Loader";

class Signup extends Component {

    login() { Actions.login() }
    createNewUser = (values) => { this.props.dispatch(createNewUser(values)) }
    onSubmit = (values) => { this.createNewUser(values) }

    renderTextInput = (field) => {
        const {meta: {touched, error}, label, secureTextEntry, maxLength, keyboardType, placeholder, input: {onChange, ...restInput}} = field;
        return (
            <View>
                <InputText
                    onChangeText={onChange}
                    maxLength={maxLength}
                    placeholder={placeholder}
                    keyboardType={keyboardType}
                    secureTextEntry={secureTextEntry}
                    label={label}
                    {...restInput} />
                    {(touched && error) && <Text style={{marginBottom: 10, fontSize: 14, color: 'red', marginTop: 0}}>{error}</Text>}
            </View>
        )
    }

    render() {
        const { handleSubmit, createUser } = this.props; 
        return (
            <Container style={styles.container}>
                {createUser.isLoading && <Loader />}
                <StatusBar backgroundColor="#102027" barStyle="light-content" />
                <Grid style={styles.gridContainer}>
                    <Row style={styles.rowContainer}>
                        <Grid style={styles.grid}>
                            <Row style={styles.rowTitle}>
                                <Text style={styles.title}>{I18n.t('signupTitle')}</Text>
                            </Row>
                            <Row style={styles.row}>
                                <Text>{I18n.t('nameLabel')}</Text>
                            </Row>
                            <Row style={styles.row}>
                                <Field
                                    name="name"
                                    placeholder={I18n.t('nameLabel')}
                                    component={this.renderTextInput} 
                                />
                            </Row>
                            <Row style={styles.row}>
                                <Text>{I18n.t('emailLabel')}</Text>
                            </Row>
                            <Row style={styles.row}>
                                <Field
                                    name="email"
                                    placeholder={I18n.t('emailLabel')}
                                    component={this.renderTextInput} 
                                />
                            </Row>
                            <Row style={styles.row}>
                                <Text>{I18n.t('passwordLabel')}</Text>
                            </Row>
                            <Row style={styles.row}>
                                <Field
                                    name="password"
                                    placeholder={I18n.t('passwordLabel')}
                                    secureTextEntry={true}
                                    component={this.renderTextInput} 
                                />
                            </Row>
                            <Row style={styles.rowButton}>
                                <View style={styles.loginContainer}>
                                    <Text style={styles.loginText}>{I18n.t('alreadyAccountText')}</Text>
                                    <TouchableOpacity onPress={this.login}>
                                        <Text style={styles.loginText}> {I18n.t('loginRefText')}</Text>
                                    </TouchableOpacity>
                                </View>
                                <Button style={styles.buttonSignup} onPress={handleSubmit(this.onSubmit)}>
                                    <Text style={styles.signText}>{I18n.t('signinButtonText')}</Text>
                                </Button>
                            </Row>
                        </Grid>
                    </Row>
                </Grid>
            </Container>
        );
    }
}

const styles = StyleSheet.create({
    container: {
      backgroundColor: "#102027"
    },
    gridContainer: {
      backgroundColor: '#102027', 
      justifyContent: 'center', 
      alignItems: 'center'
    },
    rowContainer: {
      height: 'auto', 
      backgroundColor: 'white', 
      width: 300, 
      borderWidth: 1, 
      borderColor: '#fff', 
      borderRadius: 30/2
    },
    grid: {
      alignItems: 'center'
    },
    rowTitle: {
      alignItems: 'flex-start', 
      width: 280, 
      height: 'auto', 
      marginTop: 10, 
      marginBottom: 20
    },
    rowButton: {
      alignItems: 'center', 
      width: 280, 
      height: 'auto', 
      justifyContent: 'space-between', 
      marginBottom: 10
    },
    title: {
      fontSize: 20
    },
    row: {
      alignItems: 'flex-start', 
      width: 280, 
      height: 'auto'
    },
    buttonSignup: {
      backgroundColor: "#102027",
      borderRadius: 30/2
    },
    signupText: {
        color: '#fff',
    },
    loginContainer: {
      justifyContent: 'center',
      flexDirection: 'row',
    }, 
    loginText: {
      color: '#102027', 
      fontSize: 16
    }
});

const validate = (values) => {
    const error = {};
    if(!values.name){
        error.name = I18n.t('nameRequired')
    }else if(values.name.length < 2){
        error.name = I18n.t('nameCharacters')
    }
    if(!values.email){
        error.email = I18n.t('emailRequired')
    }else if(values.email.length < 6){
        error.email = I18n.t('emailCharacters')
    }
    if(!values.password){
        error.password = I18n.t('passwordRequired')
    }else if(values.password.length < 8){
        error.password = I18n.t('passwordCharacters')
    }
    return error;
}

mapStateToProps = (state) => ({ createUser: state.authReducer.createUser });
mapDispatchToProps = (dispatch) => ({ dispatch }); 

export default compose(
    connect(mapStateToProps, mapDispatchToProps),
    reduxForm({ form: 'register', validate })
)(Signup)
